==> ejc-sealm-impl-3.0.0-20220815.062743-112-sources.jar: com/ejianc/business/sealm/mapper/ZcyysqSignatureMapper.java <==
package com.ejianc.business.sealm.mapper;

import com.ejianc.business.sealm.bean.ZzyzEntity;
import com.ejianc.framework.skeleton.template.BaseCrudMapper;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Update;

/**
 *
 * 
 * @author generator
 * 
 */
@Mapper
public interface ZcyysqSignatureMapper extends BaseCrudMapper<ZzyzEntity> {
    //劳务/专业分包正式
    @Update("update  `ejc-prosub`.`ejc_prosub_contract` set filing_status = 1   where id = #{contractId}")
    Integer updateLwfbStatus(Long contractId);

    //劳务/专业分包变更
    @Update("update  `ejc-prosub`.`ejc_prosub_contract_change` set filing_status = 1   where id = #{contractId}")
    Integer updateLwfbbgStatus(Long contractId);

    //消耗材采购合同
    @Update("update  `ejc-promaterial`.`promaterial` set filing_status = 1   where id = #{contractId}")
    Integer updateXhcStatus(Long contractId);

    //消耗材采购合同(变更)
    @Update("update  `ejc-promaterial`.`promaterial` set filing_status = 1   where id = #{contractId}")
    Integer updateXhcbgStatus(Long contractId);

    //周转材租赁正式
    @Update("update  `ejc-prormat`.`ejc_prormat_contract` set filing_status = 1   where id = #{contractId}")
    Integer updateZzcStatus(Long contractId);

    //周转材租赁变更
    @Update("update  `ejc-prormat`.`ejc_prormat_contract_change` set filing_status = 1   where id = #{contractId}")
    Integer updateZzcbgStatus(Long contractId);

    //其他支出正式
    @Update("update  `ejc-proother`.`ejc_proother_contract` set filing_status = 1   where id = #{contractId}")
    Integer updateQtzcStatus(Long contractId);

    //其他支出变更
    @Update("update  `ejc-proother`.`ejc_proother_contract_change` set filing_status = 1   where id = #{contractId}")
    Integer updateQtzcbgStatus(Long contractId);

    //机械设备安拆正式
    @Update("update  `ejc-proequipment`.`ejc_proequipment_ac_contract` set filing_status = 1   where id = #{contractId}")
    Integer updateJxsbacStatus(Long contractId);

    //机械设备安拆变更
    @Update("update  `ejc-proequipment`.`ejc_proequipment_ac_contract_change` set filing_status = 1   where id = #{contractId}")
    Integer updateJxsbacbgStatus(Long contractId);

    //机械设备租赁正式
    @Update("update  `ejc-proequipment`.`ejc_proequipment_rent_contract` set filing_status = 1   where id = #{contractId}")
    Integer updateJxsbzlStatus(Long contractId);

    //机械设备租赁变更
    @Update("update  `ejc-proequipment`.`ejc_proequipment_rent_contract_change` set filing_status = 1   where id = #{contractId}")
    Integer updateJxsbzlbgStatus(Long contractId);


    //机械设备采购正式
    @Update("update  `ejc-proequipment`.`ejc_proequipment_purchase_contract` set filing_status = 1   where id = #{contractId}")
    Integer updateJxsbcgStatus(Long contractId);

    //机械设备采购变更
    @Update("update  `ejc-proequipment`.`ejc_proequipment_purchase_contract_change` set filing_status = 1   where id = #{contractId}")
    Integer updateJxsbcgbgStatus(Long contractId);


    //施工合同评审
    @Update("update  `ejc-proincome`.`ejc_income_contract_review` set seal_flag = 1   where id = #{contractId}")
    Integer updateSghtStatus(Long contractId);
}

==> ejc-sealm-impl-3.0.0-20220923.092521-122-sources.jar: com/ejianc/business/sealm/mapper/ZcyysqSignatureMapper.java <==
package com.ejianc.business.sealm.mapper;

import com.ejianc.business.sealm.bean.ZzyzEntity;
import com.ejianc.framework.skeleton.template.BaseCrudMapper;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Update;

import java.util.Date;

/**
 *
 * 
 * @author generator
 * 
 */
@Mapper
public interface ZcyysqSignatureMapper extends BaseCrudMapper<ZzyzEntity> {
    //劳务/专业分包正式
    @Update("update  `ejc-prosub`.`ejc_prosub_contract` set filing_status = 1   where id = #{contractId}")
    Integer updateLwfbStatus(Long contractId);

    //劳务/专业分包变更
    @Update("update  `ejc-prosub`.`ejc_prosub_contract_change` set filing_status = 1   where id = #{contractId}")
    Integer updateLwfbbgStatus(Long contractId);

    //消耗材采购合同
    @Update("update  `ejc-promaterial`.`promaterial` set filing_status = 1   where id = #{contractId}")
    Integer updateXhcStatus(Long contractId);

    //消耗材采购合同(变更)
    @Update("update  `ejc-promaterial`.`promaterial` set filing_status = 1   where id = #{contractId}")
    Integer updateXhcbgStatus(Long contractId);

    //周转材租赁正式
    @Update("update  `ejc-prormat`.`ejc_prormat_contract` set filing_status = 1   where id = #{contractId}")
    Integer updateZzcStatus(Long contractId);

    //周转材租赁变更
    @Update("update  `ejc-prormat`.`ejc_prormat_contract_change` set filing_status = 1   where id = #{contractId}")
    Integer updateZzcbgStatus(Long contractId);

    //其他支出正式
    @Update("update  `ejc-proother`.`ejc_proother_contract` set filing_status = 1   where id = #{contractId}")
    Integer updateQtzcStatus(Long contractId);

    //其他支出变更
    @Update("update  `ejc-proother`.`ejc_proother_contract_change` set filing_status = 1   where id = #{contractId}")
    Integer updateQtzcbgStatus(Long contractId);

    //机械设备安拆正式
    @Update("update  `ejc-proequipment`.`ejc_proequipment_ac_contract` set filing_status = 1   where id = #{contractId}")
    Integer updateJxsbacStatus(Long contractId);

    //机械设备安拆变更
    @Update("update  `ejc-proequipment`.`ejc_proequipment_ac_contract_change` set filing_status = 1   where id = #{contractId}")
    Integer updateJxsbacbgStatus(Long contractId);

    //机械设备租赁正式
    @Update("update  `ejc-proequipment`.`ejc_proequipment_rent_contract` set filing_status = 1   where id = #{contractId}")
    Integer updateJxsbzlStatus(Long contractId);

    //机械设备租赁变更
    @Update("update  `ejc-proequipment`.`ejc_proequipment_rent_contract_change` set filing_status = 1   where id = #{contractId}")
    Integer updateJxsbzlbgStatus(Long contractId);


    //机械设备采购正式
    @Update("update  `ejc-proequipment`.`ejc_proequipment_purchase_contract` set filing_status = 1   where id = #{contractId}")
    Integer updateJxsbcgStatus(Long contractId);

    //机械设备采购变更
    @Update("update  `ejc-proequipment`.`ejc_proequipment_purchase_contract_change` set filing_status = 1   where id = #{contractId}")
    Integer updateJxsbcgbgStatus(Long contractId);


    //施工合同评审
    @Update("update  `ejc-proincome`.`ejc_income_contract_review` set seal_flag = 1 , seal_date = #{date}   where id = #{contractId}")
    Integer updateSghtStatus(Long contractId, Date date);
}
